;; Essential stuff to load.
;; This includes starting the package manager, setting the theme etc.

;; Disable custom adding stuff to init.el by making it add stuff to a file in /tmp instead.
;; Thanks Christopher Wellons! (first comment at https://irreal.org/blog/?p=3765)
(setq custom-file (make-temp-file "emacs-custom"))

;; call package-initialize manually, disable automatic initialization:
(setq package-enable-at-startup nil)

;; Hello, yes this is me.
(setq user-mail-address "opfez@disroot.org")
(setq user-full-name "opfez")
(setq add-log-mailing-address "opfez@disroot.org")

;; If this isn't set, we can't download packages. It's weird.
(setq gnutls-algorithm-priority "NORMAL:-VERS-TLS1.3")

;; Manually installed modes.
(add-to-list 'load-path "~/.emacs.d/elisp/")

;; Package
(require 'package)
(setq package-archives '(("gnu" . "http://mirrors.163.com/elpa/gnu/")
                         ("melpa" . "https://melpa.org/packages/")))
(package-initialize)

;; Set up use-package for installing all other packages.
(unless (package-installed-p 'use-package)
  (package-refresh-contents)
  (package-install 'use-package))

;; Autothemer is required for the theme I'm using, so it's essential!
(use-package autothemer
  :ensure t)

;; Load custom colour scheme.
(add-to-list 'custom-theme-load-path "~/.emacs.d/themes/")
(load-theme 'magik t)

;; Make the cursor visible in new frames
(defun fez/correct-cursor-colour (frame)
  (modify-frame-parameters frame
                           '((cursor-color . "#ffffff"))))
(add-hook 'after-make-frame-functions 'fez/correct-cursor-colour)
